-- Created		01/12/2004
-- Modified:	18/10/2019
-- Project		Paghe Open
-- Model		Anag (Db)
-- Company		Iubar.it (http://www.iubar.it)
-- Author		ing. Andrea Borgogelli Avveduti (info@iubar.it)
-- Version:		01.45.00
-- Database		Firebird

/******************************************************************************/
/****                                DB                                    ****/
/******************************************************************************/

CREATE DATABASE 'localhost:C:\Users\Iubar\AppData\Local\Temp\fdb\anag.fdb'
USER 'SYSDBA' PASSWORD 'masterkey'
PAGE_SIZE 4096
DEFAULT CHARACTER SET UTF8;

SET ECHO OFF ;

/******************************************************************************/
/****                   	ISQL INFO		                           ****/
/******************************************************************************/

 SELECT
     CURRENT_DATE,
     CURRENT_TIME,
     CURRENT_TIMESTAMP
 FROM RDB$DATABASE;

-- SHOW SQL DIALECT;

SET ECHO OFF;


/******************************************************************************/
/****                                Domains                               ****/
/******************************************************************************/


Create Domain Currency As Decimal(15,6);
Create Domain Percentage As Decimal(7,6);
Create Domain Booleanint As Smallint CHECK (value is null or value in (0, 1));
Create Domain Arithmetic As Decimal(6,2);
Create Domain Note As Varchar(500);
Create Domain IdUser As Varchar(50);


SET ECHO ON ;

/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

SET ECHO OFF ;


Create Table Anagrafica  (
	IdAnagrafica Integer NOT NULL,
	IdTipoAnagrafica Smallint NOT NULL,
	Impresa Booleanint,
	UltimaModifica Timestamp,
	UltimaModificaUser IdUser,
Constraint pk_Anagrafica Primary Key (IdAnagrafica)
);

Create Table PersonaGiuridica  (
	IdAnagrafica Integer NOT NULL,
	IdTipoPersonaGiuridica Smallint,
	IdIndirizzoLegale Integer,
	IdNaturaGiuridica Smallint,
	IdLegaleRapp Integer,
	IdContatto Integer,
	RagioneSociale Varchar(100),
	PIva Varchar(11) NOT NULL UNIQUE,
	Cf Varchar(16),
	CostituzioneData Date,
	IdFirmatario Integer,
	Tel Varchar(20),
	Fax Varchar(20),
	Email Varchar(50),
	Pec Varchar(50),
	Web Varchar(50),
Constraint pk_PersonaGiuridica Primary Key (IdAnagrafica)
);

Create Table Sindacato  (
	IdSindacato Integer NOT NULL,
	IdTipoSindacato Varchar(5),
	SedeComune Varchar(8),
	Descrizione Varchar(200),
	SedeIndirizzo Varchar(100),
	SedeLocalita Varchar(50),
	SedeCap Varchar(10),
	Tel Varchar(20),
	Fax Varchar(20),
	Email Varchar(50),
Constraint pk_Sindacato Primary Key (IdSindacato)
);

Create Table TipoAnagrafica  (
	IdTipoAnagrafica Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoAnagrafica Primary Key (IdTipoAnagrafica)
);

Create Table Subordinato  (
	IdLavoratore Integer NOT NULL,
	IdAssunzione Integer,
	IdInpsQualifica1 Varchar(2),
	IdInpsQualifica2 Varchar(2),
	IdInpsQualifica3 Varchar(2),
	IdInpsTipoLavoratore Varchar(3),
	IdInpsTipoContribuzione Varchar(8),
	IdInpsSettore Integer,
	IdInpsContratto Varchar(4),
	IdInpsTipoApprendistato Varchar(4),
	IdContrattoDettaglio Integer,
	IdLivello Varchar(5),
	IdCessazione Integer,
	Cartellino Varchar(20),
	ScattiAnzianita Smallint,
	AssunzioneDataConvenz Date,
	PartTimeContratto Percentage,
	PeriodoDal Date,
	PeriodoAl Date,
	ScadenzaQualifica3 Date,
	ScadenzaQualifica2 Date,
	ScadenzaTipoContrib Date,
Constraint pk_Subordinato Primary Key (IdLavoratore)
);

Create Table PersonaFisica  (
	IdAnagrafica Integer NOT NULL,
	IdTipoPersonaFisica Smallint,
	Sesso Smallint,
	Nome Varchar(50),
	Cognome Varchar(50),
	Cf Varchar(16) NOT NULL UNIQUE,
	IdIndirizzoDomicilio Integer,
	IdIndirizzoResidenza Integer,
	IdContatto Integer,
	Email Varchar(50),
	Tel Varchar(20),
	Cell Varchar(20),
	Fax Varchar(20),
	IdStatoCivile Smallint,
	NascitaData Date,
	NascitaComune Varchar(8),
	NascitaStato Integer,
	Cittadinanza Integer,
	Disabile Booleanint,
	DisabilePercentuale Percentage,
	IdTitoloStudio Varchar(15),
	IdPosizioneBancaria Integer,
	Orfano Booleanint,
	PensioneSuperstiti Booleanint,
	IdTipoOccupazione Smallint,
	IdTipoDatore Smallint,
	Nascosto Smallint,
	IdExtraCe Integer,
Constraint pk_PersonaFisica Primary Key (IdAnagrafica)
);

Create Table SedeImpresa  (
	IdImpresa Integer NOT NULL,
	IdSedeImpresa Smallint NOT NULL,
	IdTipoSede Smallint,
	IdIndirizzo Integer,
	IdSedeInail Integer,
	IdSedeInps Varchar(5),
	Descrizione Varchar(200),
	IdContatto Integer,
	Tel Varchar(20),
	Fax Varchar(20),
	Email Varchar(50),
	DataPatrono Date,
	InpsCsc Varchar(5),
	Accentramento Booleanint,
	UnitaOperativa Integer,
	UnitaProduttiva Integer,
Constraint pk_SedeImpresa Primary Key (IdImpresa,IdSedeImpresa)
);

Create Table Comune  (
	IdComune Varchar(8) NOT NULL,
	IdProvincia Varchar(4) NOT NULL,
	Denominazione Varchar(100),
	CodCatastale Varchar(5),
	Soppresso Booleanint,
Constraint pk_Comune Primary Key (IdComune)
);

Create Table StatoEstero  (
	IdStatoEstero Integer NOT NULL,
	IdArea Smallint NOT NULL,
	Denominazione Varchar(200),
	Denominazione2 Varchar(200),
	Denominazione3 Varchar(200),
	Cittadinanza Varchar(200),
	Cittadinanza2 Varchar(200),
	IdAgenziaEntrate Integer,
	IdStatoEsteroInps Integer,
	IdStatoEsteroInail Varchar(5),
	IdStatoEsteroCo Varchar(5),
	FinanzeCod Varchar(5),
	FinanzeCodData Date,
	Ue Smallint,
Constraint pk_StatoEstero Primary Key (IdStatoEstero)
);

Create Table Sesso  (
	IdSesso Smallint NOT NULL,
	Sesso Varchar(1),
Constraint pk_Sesso Primary Key (IdSesso)
);

Create Table StatoCivile  (
	IdStatoCivile Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_StatoCivile Primary Key (IdStatoCivile)
);

Create Table Parasubordinato  (
	IdLavoratore Integer NOT NULL,
	IdInailAliquota Integer,
	InailAliquotaAnno Integer,
	IdInpsAliquota Varchar(5),
	InpsAliquotaAnno Integer,
	IdInpsTipoRapporto Varchar(3),
	IdInpsAttivita Varchar(3),
	IdInpsAltreAss Varchar(4),
	IdInpsCalamita Varchar(3),
	IdInpsCertificazione Varchar(4),
	IscrittoGestioneSeparata Booleanint,
	CompensoLordoAnnuo Currency,
	PeriodoDal Date,
	PeriodoAl Date,
	CessazioneData Date,
Constraint pk_Parasubordinato Primary Key (IdLavoratore)
);

Create Table Istat_TitoloStudio  (
	IdTitoloStudio Varchar(15) NOT NULL,
	Liv1 Varchar(3),
	Liv2 Varchar(3),
	Liv3 Varchar(3),
	Liv4 Varchar(3),
	Liv5 Varchar(3),
	Liv6 Varchar(3),
	TitoloStudio Varchar(200),
	CodLivello Varchar(5),
	Titolo Varchar(5),
	TipoScuola Varchar(5),
	SinonimoTitolo Varchar(10),
	Field1 Varchar(200),
	Field2 Varchar(200),
Constraint pk_Istat_TitoloStudio Primary Key (IdTitoloStudio)
);

Create Table DbInfo  (
	Id Smallint NOT NULL,
	Descrizione Varchar(200),
	Valore Note,
 Primary Key (Id)
);

Create Table SedeInps  (
	IdSedeInps Varchar(5) NOT NULL,
	Denominazione Varchar(100),
	ProvinciaSigla Varchar(4),
	IdProvincia Varchar(4),
Constraint pk_SedeInps Primary Key (IdSedeInps)
);

Create Table SedeInail  (
	IdSedeInail Integer NOT NULL,
	Denominazione Varchar(100),
	Indirizzo Varchar(200),
	Cap Varchar(6),
	Citta Varchar(100),
	ProvinciaSigla Varchar(4),
	IdProvincia Varchar(4),
Constraint pk_SedeInail Primary Key (IdSedeInail)
);

Create Table SedeEnpals  (
	IdSedeEnpals Varchar(4) NOT NULL,
	Denominazione Varchar(100),
	ProvinciaSigla Varchar(4),
	IdProvincia Varchar(4),
Constraint pk_SedeEnpals Primary Key (IdSedeEnpals)
);

Create Table SedeDmag  (
	IdSedeDmag Varchar(4) NOT NULL,
	Denominazione Varchar(200),
	ProvinciaSigla Varchar(4),
	IdProvincia Varchar(4),
Constraint pk_SedeDmag Primary Key (IdSedeDmag)
);

Create Table Lavoratore  (
	IdLavoratore Integer NOT NULL,
	IdAnagrafica Integer NOT NULL,
	IdImpresa Integer NOT NULL,
	IdSedeImpresa Smallint,
	AssunzioneData Date,
	AssunzioneIdPosizione Integer,
	CessazioneData Date,
	CessazioneIdPosizione Integer,
	IdProfessione Varchar(15),
	MatricolaInps Varchar(20),
	IdTipoLavoratore Smallint,
	IdTipoLavoratore2 Smallint,
	IdTipoLavoratoreStat Varchar(5),
	IdComuneDiLavoro Varchar(8),
	IdStatoDiLavoro Integer,
	IdIndirizzoDomicilio Integer,
	IdIndirizzoDomicilio2 Integer,
	SocioLavoratore Booleanint,
	IdProfilo Integer,
	IdEntePrevidenziale Smallint,
	IdStatoLavoratore Smallint,
	InailCod Varchar(20),
	IdInailQualifica Varchar(2),
	IdInailProfessione Smallint,
	IdInailTipoRapporto Smallint,
	IdDestinazione5M Varchar(16),
	IdTipoSindacato Varchar(5),
	PrimaOccupazione Smallint,
	Note Note,
	UltimaModifica Timestamp,
	UltimaModificaUser IdUser,
Constraint pk_Lavoratore Primary Key (IdLavoratore)
);

Create Table TipoLavoratore  (
	IdTipoLavoratore Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoLavoratore Primary Key (IdTipoLavoratore)
);


Create Table TitolareDati  (
	IdTitolareDati Integer NOT NULL,
	IdTipoTitolare Smallint NOT NULL,
	IdSesso Smallint,
	PIva Varchar(20),
	IdTipoCarica Smallint,
	Cf Varchar(20),
	Cognome Varchar(50),
	Nome Varchar(50),
	Denominazione Varchar(100),
	IdIndirizzoDomicilio Integer,
	IdPosizioneBancaria Integer,
	IdContatto Integer,
	Web Varchar(50),
	Tel Varchar(50),
	Fax Varchar(50),
	Cell Varchar(50),
	Pec Varchar(50),
	EmailNome Varchar(50),
	EmailIndirizzo Varchar(50),
	EmailOggetto Varchar(20),
	EmailSoloTesto Booleanint,
	EmailTesto Varchar(1000),
	NascitaData Date,
	NascitaComune Varchar(8),
	F24CbiQualificatoreFlusso Varchar(50),
	F24CbiCodSiaAbi Varchar(50),
	F24CbiCodSia Varchar(50),
	IdSedeInps Varchar(5),
	IdSedeInail Integer,
	IdSedeEntratel Varchar(3),
	IdAeAbilitaz Smallint,
	IdAeTipo Smallint,
	InailProgresStart Integer,
	InailProgresLast Integer,
	Dm10Autorizzazione Varchar(8),
	PinSmartCard Varchar(20),
	CnceIdTitolare Varchar(5),
	IdCoSoggetto Smallint,
	InailNumUnicaAutoriz Varchar(20),
	InailNumUnicaData Date,
	IdSmtpAccount Smallint,
	Predefinito Booleanint,
Constraint pk_TitolareDati Primary Key (IdTitolareDati)
);


Create Table Provincia  (
	IdProvincia Varchar(4) NOT NULL,
	IdRegione Varchar(3) NOT NULL,
	Sigla Varchar(4),
	Denominazione Varchar(100),
Constraint pk_Provincia Primary Key (IdProvincia)
);

Create Table Regione  (
	IdRegione Varchar(3) NOT NULL,
	Denominazione Varchar(50),
	RipartizioneGeografica Varchar(30),
	CodAgenziaEntrate Varchar(4),
Constraint pk_Regione Primary Key (IdRegione)
);

Create Table StatoLavoratore  (
	IdStatoLavoratore Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_StatoLavoratore Primary Key (IdStatoLavoratore)
);

Create Table Utente  (
	Username Varchar(50) NOT NULL,
	IdAnagrafica Integer NOT NULL,
	IdTitolareDati Integer,
	IdRuolo Smallint NOT NULL,
	PwdHash Varchar(50),
	PwdSalt Varchar(50),
	Email Varchar(50),
	CreazioneData Date,
	UltimoAccesso Timestamp,
	Attivo Booleanint,
Constraint pk_Utente Primary Key (Username)
);

Create Table TipoTitolare  (
	IdTipoTitolare Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoTitolare Primary Key (IdTipoTitolare)
);

Create Table Impresa  (
	IdImpresa Integer NOT NULL,
	IdStatoSocietario Smallint,
	IdFormaGiuridica Smallint,
	IdAteco Varchar(8),
	AtecoVersione Smallint,
	IdTipoDatore Smallint,
	PIva Varchar(11),
	Cf Varchar(16),
	Denominazione Varchar(200),
	AttivitaInizioData Date,
	AttivitaCessazioneData Date,
	CciaaData Date,
	CciaaNumero Integer,
	Fatturato Currency,
	InailCodDitta Varchar(20),
	InailControCod Varchar(5),
	InailPin Varchar(10),
	InailRateazione Booleanint,
	IdTitolareDati Integer,
	IdStatoImpresa Smallint,
	Attiva Booleanint,
	IdTipoGestione Smallint,
	Note Note,
Constraint pk_Impresa Primary Key (IdImpresa)
);

Create Table SedeImpresa_Pat  (
	IdImpresa Integer NOT NULL,
	IdSedeImpresa Smallint NOT NULL,
	Pat Varchar(20) NOT NULL,
Constraint pk_SedeImpresa_Pat Primary Key (IdImpresa,IdSedeImpresa,Pat)
);

Create Table FormaGiuridicaCategoria  (
	IdCategoria Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_FormaGiuridicaCategoria Primary Key (IdCategoria)
);

Create Table FormaGiuridica  (
	IdFormaGiuridica Smallint NOT NULL,
	IdCategoria Smallint NOT NULL,
	Descrizione Varchar(100),
Constraint pk_FormaGiuridica Primary Key (IdFormaGiuridica)
);

Create Table Istat_Ateco  (
	IdAteco Varchar(8) NOT NULL,
	AtecoVersione Smallint NOT NULL,
	IdCategoria1 Varchar(3),
	AtecoVersione1 Smallint NOT NULL,
	Descrizione Note,
Constraint pk_Istat_Ateco Primary Key (IdAteco,AtecoVersione)
);

Create Table Istat_AtecoCategoria1  (
	IdCategoria1 Varchar(3) NOT NULL,
	AtecoVersione1 Smallint NOT NULL,
	IdCategoria2 Varchar(2),
	AtecoVersione2 Smallint NOT NULL,
	Descrizione Varchar(500),
	Note Varchar(4000),
Constraint pk_Istat_AtecoCategoria1 Primary Key (IdCategoria1,AtecoVersione1)
);

Create Table TipoSocio  (
	IdTipoSocio Smallint NOT NULL,
	Descrizione Varchar(400),
Constraint pk_TipoSocio Primary Key (IdTipoSocio)
);

Create Table Socio  (
	IdImpresa Integer NOT NULL,
	IdAnagrafica Integer NOT NULL,
	IdTipoSocio Smallint,
	EntrataData Date,
	UscitaData Date,
	Note Note,
Constraint pk_Socio Primary Key (IdImpresa,IdAnagrafica)
);

Create Table StatoArea  (
	IdArea Smallint NOT NULL,
	IdContinente Smallint,
	Denominazione Varchar(100),
Constraint pk_StatoArea Primary Key (IdArea)
);

Create Table Cap  (
	IdCap Integer NOT NULL,
	Capi Varchar(6) NOT NULL,
	Prov Varchar(4),
	Comu Varchar(200),
	Com2 Varchar(200),
	Fraz Varchar(200),
	Fra2 Varchar(200),
	Topo Varchar(200),
	Top2 Varchar(200),
	Dugt Varchar(200),
	Nciv Varchar(50),
Constraint pk_Cap Primary Key (IdCap)
);

Create Table AE_NaturaGiuridica  (
	IdNaturaGiuridica Smallint NOT NULL,
	Descrizione Varchar(500),
	NonResidente Booleanint,
Constraint pk_AE_NaturaGiuridica Primary Key (IdNaturaGiuridica)
);

Create Table AE_StatoSocietario  (
	IdStatoSocietario Smallint NOT NULL,
	Descrizione Varchar(500),
Constraint pk_AE_StatoSocietario Primary Key (IdStatoSocietario)
);

Create Table Banca_Abi  (
	Abi Varchar(5) NOT NULL,
	Descrizione Varchar(400),
	Data Date,
	IdStato Smallint,
	Sostituto Varchar(5),
Constraint pk_Banca_Abi Primary Key (Abi)
);

Create Table Banca_Cab  (
	Cab Varchar(5) NOT NULL,
	Abi Varchar(5) NOT NULL,
	Bic Varchar(11),
	Filiale Varchar(100),
	Indirizzo Varchar(100),
	Localita Varchar(50),
	Cap Varchar(6),
	ProvinciaSigla Varchar(4),
	Data Date,
	Custom Booleanint,
Constraint pk_Banca_Cab Primary Key (Cab,Abi)
);

Create Table CentroDiCosto_Lavoratore  (
	IdLavoratore Integer NOT NULL,
	IdImpresa Integer NOT NULL,
	IdCentroDiCosto Smallint NOT NULL,
	Percentuale Percentage NOT NULL,
	Decorrenza Date,
Constraint pk_CentroDiCosto_Lavoratore Primary Key (IdLavoratore,IdImpresa,IdCentroDiCosto,Percentuale)
);

Create Table CentroDiCosto_SedeImpresa  (
	IdImpresa Integer NOT NULL,
	IdCentroDiCosto Smallint NOT NULL,
	IdSedeImpresa Smallint NOT NULL,
Constraint pk_CentroDiCosto_SedeImpresa Primary Key (IdImpresa,IdCentroDiCosto,IdSedeImpresa)
);

Create Table Banca_Dettagli  (
	Cab Varchar(5) NOT NULL,
	Abi Varchar(5) NOT NULL,
	Tel Varchar(20),
	Fax Varchar(20),
	Email Varchar(50),
	Web Varchar(200),
Constraint pk_Banca_Dettagli Primary Key (Cab,Abi)
);

Create Table Impresa_Banca  (
	IdImpresa Integer NOT NULL,
	IdSedeImpresa Smallint NOT NULL,
	IdPosizioneBancaria Integer NOT NULL,
	Descrizione Varchar(200),
	Predefinito Booleanint,
	PerTutte Booleanint,
Constraint pk_Impresa_Banca Primary Key (IdImpresa,IdSedeImpresa,IdPosizioneBancaria)
);

Create Table TipoPersonaFisica  (
	IdTipoPersonaFisica Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoPersonaFisica Primary Key (IdTipoPersonaFisica)
);

Create Table TipoPersonaGiuridica  (
	IdTipoPersonaGiuridica Smallint NOT NULL,
	Descrizione Varchar(200),
	InpsCod Varchar(2),
Constraint pk_TipoPersonaGiuridica Primary Key (IdTipoPersonaGiuridica)
);

Create Table TipoLavoratore2  (
	IdTipoLavoratore2 Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoLavoratore2 Primary Key (IdTipoLavoratore2)
);

Create Table RapportoParentela  (
	IdRapportoParentela Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_RapportoParentela Primary Key (IdRapportoParentela)
);

Create Table Parentela  (
	IdAnagrafica1 Integer NOT NULL,
	IdRapportoParentela Smallint NOT NULL,
	IdAnagrafica2 Integer NOT NULL,
	IdStatoParentela Smallint,
	Convivente Booleanint,
	RiceveAssegno Booleanint,
	RedditoAnno Currency,
	ACarico Booleanint,
	ACaricoDal Date,
	ACaricoAl Date,
	ACaricoPercentuale Percentage,
	RapportoDal Date,
	RapportoAl Date,
	Opzione Smallint,
Constraint pk_Parentela Primary Key (IdAnagrafica1,IdRapportoParentela,IdAnagrafica2)
);

Create Table StatoParentela  (
	IdStatoParentela Smallint NOT NULL,
	Descrizione Varchar(100),
Constraint pk_StatoParentela Primary Key (IdStatoParentela)
);

Create Table Istat_AtecoCategoria2  (
	IdCategoria2 Varchar(2) NOT NULL,
	AtecoVersione2 Smallint NOT NULL,
	Descrizione Varchar(500),
	Note Varchar(2000),
Constraint pk_Istat_AtecoCategoria2 Primary Key (IdCategoria2,AtecoVersione2)
);

Create Table Istat_Professione  (
	IdProfessione Varchar(15) NOT NULL,
	Descrizione Note,
	Validodal Date,
Constraint pk_Istat_Professione Primary Key (IdProfessione)
);

Create Table CentroDiCosto  (
	IdImpresa Integer NOT NULL,
	IdCentroDiCosto Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_CentroDiCosto Primary Key (IdImpresa,IdCentroDiCosto)
);

Create Table TipoSede  (
	IdTipoSede Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoSede Primary Key (IdTipoSede)
);

Create Table StatoImpresa  (
	IdStatoImpresa Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_StatoImpresa Primary Key (IdStatoImpresa)
);

Create Table PosizioneBancaria  (
	IdPosizioneBancaria Integer NOT NULL,
	Cab Varchar(5),
	Abi Varchar(5),
	Cc Varchar(12),
	Cin Varchar(1),
	Iban Varchar(27),
	Bic Varchar(11),
	Bic2 Varchar(11),
	Note Varchar(400),
Constraint pk_PosizioneBancaria Primary Key (IdPosizioneBancaria)
);

Create Table Azione  (
	IdAzione Smallint NOT NULL,
	Descrizione Varchar(200),
	Note Note,
Constraint pk_Azione Primary Key (IdAzione)
);

Create Table Utente_Azione  (
	Username Varchar(50) NOT NULL,
	IdAzione Smallint NOT NULL,
	IdTarget Smallint NOT NULL,
	Custom Booleanint,
	UltimaModifica Timestamp,
Constraint pk_Utente_Azione Primary Key (Username,IdAzione,IdTarget)
);

Create Table Inps_Autorizzazione  (
	InpsCa Varchar(2) NOT NULL,
	ValidoDal Date NOT NULL,
	ValidoAl Date,
	Descrizione Note,
	Note Note,
Constraint pk_Inps_Autorizzazione Primary Key (InpsCa,ValidoDal)
);

Create Table SedeImpresa_Autorizzazione  (
	IdImpresa Integer NOT NULL,
	IdSedeImpresa Smallint NOT NULL,
	InpsCa Varchar(2) NOT NULL,
	ValidoDal Date NOT NULL,
	UltimaModifica Date,
Constraint pk_SedeImpresa_Autorizzazione Primary Key (IdImpresa,IdSedeImpresa,InpsCa,ValidoDal)
);

Create Table Inps_Csc  (
	InpsCsc Varchar(5) NOT NULL,
	IdInpsClasse Varchar(2) NOT NULL,
	IdInpsRamo Smallint NOT NULL,
	IdAttivita Varchar(2),
	Descrizione Note,
Constraint pk_Inps_Csc Primary Key (InpsCsc)
);

Create Table Inps_CaCompatibile  (
	InpsCa Varchar(2) NOT NULL,
	ProgressivoCa Smallint NOT NULL,
	InpsCaCompatibile Varchar(2) NOT NULL,
	ProgressivoCaComp Smallint NOT NULL,
	ValidoDal Date,
	ValidoAl Date,
Constraint pk_Inps_CaCompatibile Primary Key (InpsCa,ProgressivoCa,InpsCaCompatibile,ProgressivoCaComp)
);

Create Table Inps_Autorizzazione_Csc  (
	InpsCa Varchar(2) NOT NULL,
	ProgressivoCa Smallint NOT NULL,
	InpsCsc Varchar(5) NOT NULL,
	Compatibile Smallint,
	ValidoDal Date,
	ValidoAl Date,
Constraint pk_Inps_Autorizzazione_Csc Primary Key (InpsCa,ProgressivoCa,InpsCsc)
);

Create Table Inps_CaIncompatibile  (
	InpsCa Varchar(2) NOT NULL,
	ProgressivoCa Smallint NOT NULL,
	InpsCaIncompatibile Varchar(2) NOT NULL,
	ProgressivoCaIncomp Smallint NOT NULL,
	ValidoDal Date,
	ValidoAl Date,
Constraint pk_Inps_CaIncompatibile Primary Key (InpsCa,ProgressivoCa,InpsCaIncompatibile,ProgressivoCaIncomp)
);

Create Table Inps_Classe  (
	IdInpsClasse Varchar(2) NOT NULL,
	IdInpsRamo Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Inps_Classe Primary Key (IdInpsClasse,IdInpsRamo)
);

Create Table Inps_Ramo  (
	IdInpsRamo Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Inps_Ramo Primary Key (IdInpsRamo)
);

Create Table Istat_AtecoRaccordo  (
	IdAtecoNew Varchar(8) NOT NULL,
	AtecoNewVersione Smallint NOT NULL,
	IdAtecoOld Varchar(8),
	AtecoOldVersione Smallint,
	ValidoDal Date,
Constraint pk_Istat_AtecoRaccordo Primary Key (IdAtecoNew,AtecoNewVersione)
);

Create Table CassaEdile  (
	IdCassaEdile Varchar(5) NOT NULL,
	IdTipo Smallint,
	IdProvincia Varchar(4),
	IdRegione Varchar(3),
	Denominazione Varchar(200),
Constraint pk_CassaEdile Primary Key (IdCassaEdile)
);

Create Table Toponimo  (
	IdToponimo Smallint NOT NULL,
	Descrizione Varchar(200),
	Descrizione2 Varchar(10),
	IdStatoEstero Integer,
Constraint pk_Toponimo Primary Key (IdToponimo)
);

Create Table Asl  (
	IdAsl Varchar(5) NOT NULL,
	Denominazione Varchar(200),
	Comune Varchar(50),
	ProvinciaSigla Varchar(4),
Constraint pk_Asl Primary Key (IdAsl)
);

Create Table SedeInpdap  (
	IdSedeInpdap Varchar(5) NOT NULL,
	Denominazione Varchar(200),
	ProvinciaSigla Varchar(4),
	IdProvincia Varchar(4),
Constraint pk_SedeInpdap Primary Key (IdSedeInpdap)
);

Create Table SedeInpdai  (
	IdSedeInpdai Varchar(5) NOT NULL,
	Denominazione Varchar(200),
	ProvinciaSigla Varchar(4),
	IdProvincia Varchar(4),
Constraint pk_SedeInpdai Primary Key (IdSedeInpdai)
);

Create Table AE_EnteLocale  (
	IdEnteLocale Smallint NOT NULL,
	Territorio Varchar(200),
Constraint pk_AE_EnteLocale Primary Key (IdEnteLocale)
);

Create Table Co_StatusStraniero  (
	IdStatusStraniero Smallint NOT NULL,
	Descrizione Varchar(200),
	ValidoDal Date,
	ValidoAl Date,
Constraint pk_Co_StatusStraniero Primary Key (IdStatusStraniero)
);

Create Table Co_PermessoSoggiorno  (
	IdPermesso Varchar(6) NOT NULL,
	Descrizione Varchar(200),
	ValidoDal Date,
	ValidoAl Date,
Constraint pk_Co_PermessoSoggiorno Primary Key (IdPermesso)
);

Create Table Co_Soggetto  (
	IdCoSoggetto Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Co_Soggetto Primary Key (IdCoSoggetto)
);

Create Table Indirizzo  (
	IdIndirizzo Integer NOT NULL,
	IdTipoIndirizzo Smallint NOT NULL,
	IdStatoEstero Integer,
	IdComune Varchar(8),
	IdToponimo Smallint,
	Indirizzo Varchar(100),
	NumCivico Varchar(10),
	Localita Varchar(100),
	Cap Varchar(6),
Constraint pk_Indirizzo Primary Key (IdIndirizzo)
);

Create Table TipoIndirizzo  (
	IdTipoIndirizzo Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoIndirizzo Primary Key (IdTipoIndirizzo)
);

Create Table Target  (
	IdTarget Smallint NOT NULL,
	Descrizione Varchar(200),
	Note Note,
Constraint pk_Target Primary Key (IdTarget)
);

Create Table Ruolo  (
	IdRuolo Smallint NOT NULL,
	Descrizione Varchar(200),
	Note Note,
Constraint pk_Ruolo Primary Key (IdRuolo)
);

Create Table SedeImpresaPat_Voce  (
	IdImpresa Integer NOT NULL,
	IdSedeImpresa Smallint NOT NULL,
	Pat Varchar(20) NOT NULL,
	VoceTariffa Varchar(10) NOT NULL,
	IdVoceTariffa Integer,
Constraint pk_SedeImpresaPat_Voce Primary Key (IdImpresa,IdSedeImpresa,Pat,VoceTariffa)
);

Create Table Capoluogo  (
	IdComune Varchar(8) NOT NULL,
	IdRegione Varchar(3) NOT NULL,
Constraint pk_Capoluogo Primary Key (IdComune,IdRegione)
);

Create Table TipoLavoratoreStat  (
	IdTipoLavoratoreStat Varchar(5) NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoLavoratoreStat Primary Key (IdTipoLavoratoreStat)
);

Create Table TipoDatore  (
	IdTipoDatore Smallint NOT NULL,
	Descrizione Varchar(200),
	SostitutoImposta Booleanint,
Constraint pk_TipoDatore Primary Key (IdTipoDatore)
);

Create Table Ae_TipoDestinazione5M  (
	IdAeTipoDestinazione Smallint NOT NULL,
	Descrizione Note,
Constraint pk_Ae_TipoDestinazione5M Primary Key (IdAeTipoDestinazione)
);

Create Table AE_Destinazione5M  (
	IdDestinazione5M Varchar(16) NOT NULL,
	IdAeTipoDestinazione Smallint NOT NULL,
Constraint pk_AE_Destinazione5M Primary Key (IdDestinazione5M)
);

Create Table TipoSindacato  (
	IdTipoSindacato Varchar(5) NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoSindacato Primary Key (IdTipoSindacato)
);

Create Table Cantiere  (
	IdImpresa Integer NOT NULL,
	IdCantiere Smallint NOT NULL,
	IdSituazione Smallint,
	IdTipoAttivita Smallint,
	IdTipoLavoro Smallint,
	IdAppaltatore Integer,
	IdCommittente Integer,
	IdTipocommittente Smallint,
	IdIndirizzo Integer,
	DataSituazione Date,
	CodCe Varchar(10),
	CodMut Varchar(15),
	Denominazione Varchar(200),
	InizioMese Smallint,
	InizioAnno Integer,
	FineMese Smallint,
	FineAnno Integer,
	RetribImponibileInps Currency,
	RetribImponibileCe Currency,
	Trasfertisti Booleanint,
	Interinali Booleanint,
	Prevalente Booleanint,
	NpCodice Varchar(20),
	NpData Date,
	OperaValore Currency,
	OperaImporto Currency,
	OperaDataFine Date,
	AppaltoData Date,
	AppaltoProtocollo Varchar(20),
	AppaltoCip Varchar(15),
	Note Note,
Constraint pk_Cantiere Primary Key (IdImpresa,IdCantiere)
);

Create Table Cnce_TipoCommittente  (
	IdTipocommittente Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Cnce_TipoCommittente Primary Key (IdTipocommittente)
);

Create Table Cnce_TipoAttivita  (
	IdTipoAttivita Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Cnce_TipoAttivita Primary Key (IdTipoAttivita)
);

Create Table Cnce_SituazioneCantiere  (
	IdSituazione Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Cnce_SituazioneCantiere Primary Key (IdSituazione)
);

Create Table Cnce_Subappalto  (
	IdImpresa Integer NOT NULL,
	IdCantiere Smallint NOT NULL,
	IdSubAppalto Smallint NOT NULL,
	IdAppaltatore Integer,
	Denominazione Varchar(200),
	Descrizione Note,
	Importo Currency,
	DataInizio Date,
	DataFine Date,
Constraint pk_Cnce_Subappalto Primary Key (IdImpresa,IdCantiere,IdSubAppalto)
);

Create Table Cnce_Lavoratore  (
	IdLavoratore Integer NOT NULL,
	CodCe Varchar(10),
	AltraCassa Varchar(5),
	ImportoRimborsoCig Currency,
	OreTrimPrecedente Smallint,
	Note Note,
Constraint pk_Cnce_Lavoratore Primary Key (IdLavoratore)
);

Create Table Cnce_Impresa  (
	IdImpresa Integer NOT NULL,
	IdTipoContratto Smallint,
	CodCassaEdile Varchar(9),
	DestinazCe Varchar(5),
Constraint pk_Cnce_Impresa Primary Key (IdImpresa)
);

Create Table ConfigImpresa  (
	IdImpresa Integer NOT NULL,
	IdConfig Smallint NOT NULL,
	Valore Varchar(200),
Constraint pk_ConfigImpresa Primary Key (IdImpresa,IdConfig)
);

Create Table SmtpAccount  (
	IdSmtpAccount Smallint NOT NULL,
	NeedPassword Booleanint,
	SmtpUser Varchar(50),
	SmtpPassword Varchar(200),
	SmtpServer Varchar(200),
Constraint pk_SmtpAccount Primary Key (IdSmtpAccount)
);

Create Table SedeImpresa_CodInpsLav  (
	IdImpresa Integer NOT NULL,
	IdSedeImpresa Smallint NOT NULL,
	MatricolaInps Varchar(20) NOT NULL,
	ControCod Varchar(5),
Constraint pk_SedeImpresa_CodInpsLav Primary Key (IdImpresa,IdSedeImpresa,MatricolaInps)
);

Create Table TipoOccupazione  (
	IdTipoOccupazione Smallint NOT NULL,
	Descrizione Varchar(100),
	Dal Date,
Constraint pk_TipoOccupazione Primary Key (IdTipoOccupazione)
);

Create Table Reddito  (
	IdAnagrafica Integer NOT NULL,
	Anno Integer NOT NULL,
	Reddito Currency,
Constraint pk_Reddito Primary Key (IdAnagrafica,Anno)
);

Create Table Questura  (
	IdQuestura Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Questura Primary Key (IdQuestura)
);

Create Table ExtraCe  (
	IdExtraCe Integer NOT NULL,
	IdStatusStraniero Smallint,
	IdPermesso Varchar(6),
	Numero Varchar(50),
	Scadenza Date,
	IdQuestura Smallint,
	SussistenzaAbitativa Booleanint,
	ImpegnoRimpatrio Booleanint,
Constraint pk_ExtraCe Primary Key (IdExtraCe)
);

Create Table ConfigTitolareDati  (
	IdTitolareDati Integer NOT NULL,
	IdConfig Smallint NOT NULL,
	Valore Varchar(200),
Constraint pk_ConfigTitolareDati Primary Key (IdTitolareDati,IdConfig)
);

Create Table Contatto  (
	IdContatto Integer NOT NULL,
	Tel Varchar(30),
	Fax Varchar(30),
	Cell Varchar(30),
	Email Varchar(100),
	Pec Varchar(100),
	Web Varchar(100),
Constraint pk_Contatto Primary Key (IdContatto)
);

Create Table Cnce_TipoContratto  (
	IdTipoContratto Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Cnce_TipoContratto Primary Key (IdTipoContratto)
);

Create Table Cnce_TipoLavoro  (
	IdTipoLavoro Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Cnce_TipoLavoro Primary Key (IdTipoLavoro)
);

Create Table EntePubblico  (
	IdEnte Integer NOT NULL,
	IdEnteAppartenenza Integer,
	Progressivo Varchar(5),
	IdMefSpt Varchar(7),
	Mef Booleanint,
Constraint pk_EntePubblico Primary Key (IdEnte)
);

Create Table SubordinatoPa  (
	IdLavoratore Integer NOT NULL,
	IdEnte Integer,
	IdSedeServizio Integer,
	IdPaQualifica Varchar(7),
	IdTipoImpiego Smallint,
	IdTipoServizio Smallint,
	IdRegimeFineServ Smallint,
	PercRetribuzione Percentage,
	PercAspettativa Percentage,
	OreSettPersScuolaR Arithmetic,
	OreSettPersScuolaC Arithmetic,
Constraint pk_SubordinatoPa Primary Key (IdLavoratore)
);

Create Table Sp_Impresa  (
	IdImpresa Integer NOT NULL,
	IdCategoria Smallint,
	CodiceGruppo Varchar(6),
	NumeroAttivita Smallint,
Constraint pk_Sp_Impresa Primary Key (IdImpresa)
);

Create Table Sp_Categoria  (
	IdCategoria Smallint NOT NULL,
	Descrizione Varchar(200),
	ValidoDal Date,
	ValidoAl Date,
Constraint pk_Sp_Categoria Primary Key (IdCategoria)
);

Create Table Pa_Organo  (
	IdOrgano Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Pa_Organo Primary Key (IdOrgano)
);

Create Table ImpresaAgricoltura  (
	IdImpresa Integer NOT NULL,
	Cida Varchar(8),
	IdAssCategoria Varchar(2),
Constraint pk_ImpresaAgricoltura Primary Key (IdImpresa)
);

Create Table AE_TipoCarica  (
	IdTipoCarica Smallint NOT NULL,
	Descrizione Note,
Constraint pk_AE_TipoCarica Primary Key (IdTipoCarica)
);

Create Table Firmatario  (
	IdFirmatario Integer NOT NULL,
	IdTipoCarica Smallint,
Constraint pk_Firmatario Primary Key (IdFirmatario)
);

Create Table Cantiere_CnceLav  (
	IdImpresa Integer NOT NULL,
	IdCantiere Smallint NOT NULL,
	IdLavoratore Integer NOT NULL,
	Dal Date,
	Al Date,
Constraint pk_Cantiere_CnceLav Primary Key (IdImpresa,IdCantiere,IdLavoratore)
);

Create Table Continente  (
	IdContinente Smallint NOT NULL,
	Denominazione Varchar(100),
Constraint pk_Continente Primary Key (IdContinente)
);

COMMIT WORK;


/******************************************************************************/
/****                                Indexes                               ****/
/******************************************************************************/

Alter Table PersonaGiuridica add Constraint Relationship2 Foreign Key (IdAnagrafica) references Anagrafica (IdAnagrafica) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship16 Foreign Key (IdAnagrafica) references Anagrafica (IdAnagrafica) on update no action on delete no action ;
Alter Table Impresa add Constraint Relationship170 Foreign Key (IdImpresa) references Anagrafica (IdAnagrafica) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship190 Foreign Key (IdTitolareDati) references Anagrafica (IdAnagrafica) on update no action on delete no action ;
Alter Table Cantiere add Constraint Relationship396 Foreign Key (IdCommittente) references Anagrafica (IdAnagrafica) on update no action on delete no action ;
Alter Table Cantiere add Constraint Relationship397 Foreign Key (IdAppaltatore) references Anagrafica (IdAnagrafica) on update no action on delete no action ;
Alter Table EntePubblico add Constraint Relationship398 Foreign Key (IdEnte) references PersonaGiuridica (IdAnagrafica) on update no action on delete no action ;
Alter Table Anagrafica add Constraint Relationship12 Foreign Key (IdTipoAnagrafica) references TipoAnagrafica (IdTipoAnagrafica) on update no action on delete no action ;
Alter Table SubordinatoPa add Constraint Relationship404 Foreign Key (IdLavoratore) references Subordinato (IdLavoratore) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship86 Foreign Key (IdAnagrafica) references PersonaFisica (IdAnagrafica) on update no action on delete no action ;
Alter Table Utente add Constraint Relationship95 Foreign Key (IdAnagrafica) references PersonaFisica (IdAnagrafica) on update no action on delete no action ;
Alter Table Socio add Constraint Relationship182 Foreign Key (IdAnagrafica) references PersonaFisica (IdAnagrafica) on update no action on delete no action ;
Alter Table PersonaGiuridica add Constraint Relationship225 Foreign Key (IdLegaleRapp) references PersonaFisica (IdAnagrafica) on update no action on delete no action ;
Alter Table Parentela add Constraint Relationship264 Foreign Key (IdAnagrafica1) references PersonaFisica (IdAnagrafica) on update no action on delete no action ;
Alter Table Parentela add Constraint Relationship265 Foreign Key (IdAnagrafica2) references PersonaFisica (IdAnagrafica) on update no action on delete no action ;
Alter Table Reddito add Constraint Relationship378 Foreign Key (IdAnagrafica) references PersonaFisica (IdAnagrafica) on update no action on delete no action ;
Alter Table Firmatario add Constraint Relationship421 Foreign Key (IdFirmatario) references PersonaFisica (IdAnagrafica) on update no action on delete no action ;
Alter Table CentroDiCosto_SedeImpresa add Constraint Relationship290 Foreign Key (IdImpresa,IdSedeImpresa) references SedeImpresa (IdImpresa,IdSedeImpresa) on update no action on delete no action ;
Alter Table SedeImpresa_Pat add Constraint Relationship302 Foreign Key (IdImpresa,IdSedeImpresa) references SedeImpresa (IdImpresa,IdSedeImpresa) on update no action on delete no action ;
Alter Table SedeImpresa_Autorizzazione add Constraint Relationship305 Foreign Key (IdImpresa,IdSedeImpresa) references SedeImpresa (IdImpresa,IdSedeImpresa) on update no action on delete no action ;
Alter Table Impresa_Banca add Constraint Relationship241 Foreign Key (IdImpresa,IdSedeImpresa) references SedeImpresa (IdImpresa,IdSedeImpresa) on update no action on delete no action ;
Alter Table SedeImpresa_CodInpsLav add Constraint Relationship371 Foreign Key (IdImpresa,IdSedeImpresa) references SedeImpresa (IdImpresa,IdSedeImpresa) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship34 Foreign Key (NascitaComune) references Comune (IdComune) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship97 Foreign Key (NascitaComune) references Comune (IdComune) on update no action on delete no action ;
Alter Table Sindacato add Constraint Relationship228 Foreign Key (SedeComune) references Comune (IdComune) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship274 Foreign Key (IdComuneDiLavoro) references Comune (IdComune) on update no action on delete no action ;
Alter Table Indirizzo add Constraint Relationship325 Foreign Key (IdComune) references Comune (IdComune) on update no action on delete no action ;
Alter Table Capoluogo add Constraint Relationship350 Foreign Key (IdComune) references Comune (IdComune) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship47 Foreign Key (Cittadinanza) references StatoEstero (IdStatoEstero) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship286 Foreign Key (IdStatoDiLavoro) references StatoEstero (IdStatoEstero) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship315 Foreign Key (NascitaStato) references StatoEstero (IdStatoEstero) on update no action on delete no action ;
Alter Table Indirizzo add Constraint Relationship324 Foreign Key (IdStatoEstero) references StatoEstero (IdStatoEstero) on update no action on delete no action ;
Alter Table Toponimo add Constraint Relationship339 Foreign Key (IdStatoEstero) references StatoEstero (IdStatoEstero) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship55 Foreign Key (Sesso) references Sesso (IdSesso) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship244 Foreign Key (IdSesso) references Sesso (IdSesso) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship56 Foreign Key (IdStatoCivile) references StatoCivile (IdStatoCivile) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship65 Foreign Key (IdTitoloStudio) references Istat_TitoloStudio (IdTitoloStudio) on update no action on delete no action ;
Alter Table SedeImpresa add Constraint Relationship242 Foreign Key (IdSedeInps) references SedeInps (IdSedeInps) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship243 Foreign Key (IdSedeInps) references SedeInps (IdSedeInps) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship251 Foreign Key (IdSedeInail) references SedeInail (IdSedeInail) on update no action on delete no action ;
Alter Table SedeImpresa add Constraint Relationship252 Foreign Key (IdSedeInail) references SedeInail (IdSedeInail) on update no action on delete no action ;
Alter Table Parasubordinato add Constraint Relationship87 Foreign Key (IdLavoratore) references Lavoratore (IdLavoratore) on update no action on delete no action ;
Alter Table Subordinato add Constraint Relationship88 Foreign Key (IdLavoratore) references Lavoratore (IdLavoratore) on update no action on delete no action ;
Alter Table CentroDiCosto_Lavoratore add Constraint Relationship199 Foreign Key (IdLavoratore) references Lavoratore (IdLavoratore) on update no action on delete no action ;
Alter Table Cnce_Lavoratore add Constraint Relationship367 Foreign Key (IdLavoratore) references Lavoratore (IdLavoratore) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship82 Foreign Key (IdTipoLavoratore) references TipoLavoratore (IdTipoLavoratore) on update no action on delete no action ;
Alter Table Impresa add Constraint Relationship320 Foreign Key (IdTitolareDati) references TitolareDati (IdTitolareDati) on update no action on delete no action ;
Alter Table Utente add Constraint Relationship338 Foreign Key (IdTitolareDati) references TitolareDati (IdTitolareDati) on update no action on delete no action ;
Alter Table ConfigTitolareDati add Constraint Relationship383 Foreign Key (IdTitolareDati) references TitolareDati (IdTitolareDati) on update no action on delete no action ;
Alter Table Comune add Constraint Relationship162 Foreign Key (IdProvincia) references Provincia (IdProvincia) on update no action on delete no action ;
Alter Table SedeInps add Constraint Relationship343 Foreign Key (IdProvincia) references Provincia (IdProvincia) on update no action on delete no action ;
Alter Table SedeInail add Constraint Relationship344 Foreign Key (IdProvincia) references Provincia (IdProvincia) on update no action on delete no action ;
Alter Table CassaEdile add Constraint Relationship417 Foreign Key (IdProvincia) references Provincia (IdProvincia) on update no action on delete no action ;
Alter Table Provincia add Constraint Relationship3022 Foreign Key (IdRegione) references Regione (IdRegione) on update no action on delete no action ;
Alter Table Capoluogo add Constraint Relationship351 Foreign Key (IdRegione) references Regione (IdRegione) on update no action on delete no action ;
Alter Table CassaEdile add Constraint Relationship418 Foreign Key (IdRegione) references Regione (IdRegione) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship93 Foreign Key (IdStatoLavoratore) references StatoLavoratore (IdStatoLavoratore) on update no action on delete no action ;
Alter Table Utente_Azione add Constraint Relationship299 Foreign Key (Username) references Utente (Username) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship96 Foreign Key (IdTipoTitolare) references TipoTitolare (IdTipoTitolare) on update no action on delete no action ;
Alter Table SedeImpresa add Constraint Relationship140 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table Socio add Constraint Relationship185 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship248 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table CentroDiCosto add Constraint Relationship334 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table Cantiere add Constraint Relationship360 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table Cnce_Impresa add Constraint Relationship368 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table ConfigImpresa add Constraint Relationship369 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table Sp_Impresa add Constraint Relationship415 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table ImpresaAgricoltura add Constraint Relationship419 Foreign Key (IdImpresa) references Impresa (IdImpresa) on update no action on delete no action ;
Alter Table SedeImpresaPat_Voce add Constraint Relationship346 Foreign Key (IdImpresa,IdSedeImpresa,Pat) references SedeImpresa_Pat (IdImpresa,IdSedeImpresa,Pat) on update no action on delete no action ;
Alter Table FormaGiuridica add Constraint Relationship158 Foreign Key (IdCategoria) references FormaGiuridicaCategoria (IdCategoria) on update no action on delete no action ;
Alter Table Impresa add Constraint Relationship160 Foreign Key (IdFormaGiuridica) references FormaGiuridica (IdFormaGiuridica) on update no action on delete no action ;
Alter Table Impresa add Constraint Relationship165 Foreign Key (IdAteco,AtecoVersione) references Istat_Ateco (IdAteco,AtecoVersione) on update no action on delete no action ;
Alter Table Istat_Ateco add Constraint Relationship171 Foreign Key (IdCategoria1,AtecoVersione1) references Istat_AtecoCategoria1 (IdCategoria1,AtecoVersione1) on update no action on delete no action ;
Alter Table Socio add Constraint Relationship184 Foreign Key (IdTipoSocio) references TipoSocio (IdTipoSocio) on update no action on delete no action ;
Alter Table StatoEstero add Constraint Relationship191 Foreign Key (IdArea) references StatoArea (IdArea) on update no action on delete no action ;
Alter Table PersonaGiuridica add Constraint Relationship236 Foreign Key (IdNaturaGiuridica) references AE_NaturaGiuridica (IdNaturaGiuridica) on update no action on delete no action ;
Alter Table Impresa add Constraint Relationship196 Foreign Key (IdStatoSocietario) references AE_StatoSocietario (IdStatoSocietario) on update no action on delete no action ;
Alter Table Banca_Cab add Constraint Relationship197 Foreign Key (Abi) references Banca_Abi (Abi) on update no action on delete no action ;
Alter Table Banca_Dettagli add Constraint Relationship209 Foreign Key (Cab,Abi) references Banca_Cab (Cab,Abi) on update no action on delete no action ;
Alter Table PosizioneBancaria add Constraint Relationship291 Foreign Key (Cab,Abi) references Banca_Cab (Cab,Abi) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship245 Foreign Key (IdTipoPersonaFisica) references TipoPersonaFisica (IdTipoPersonaFisica) on update no action on delete no action ;
Alter Table PersonaGiuridica add Constraint Relationship246 Foreign Key (IdTipoPersonaGiuridica) references TipoPersonaGiuridica (IdTipoPersonaGiuridica) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship249 Foreign Key (IdTipoLavoratore2) references TipoLavoratore2 (IdTipoLavoratore2) on update no action on delete no action ;
Alter Table Parentela add Constraint Relationship266 Foreign Key (IdRapportoParentela) references RapportoParentela (IdRapportoParentela) on update no action on delete no action ;
Alter Table Parentela add Constraint Relationship268 Foreign Key (IdStatoParentela) references StatoParentela (IdStatoParentela) on update no action on delete no action ;
Alter Table Istat_AtecoCategoria1 add Constraint Relationship270 Foreign Key (IdCategoria2,AtecoVersione2) references Istat_AtecoCategoria2 (IdCategoria2,AtecoVersione2) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship271 Foreign Key (IdProfessione) references Istat_Professione (IdProfessione) on update no action on delete no action ;
Alter Table CentroDiCosto_Lavoratore add Constraint Relationship345 Foreign Key (IdImpresa,IdCentroDiCosto) references CentroDiCosto (IdImpresa,IdCentroDiCosto) on update no action on delete no action ;
Alter Table SedeImpresa add Constraint Relationship281 Foreign Key (IdTipoSede) references TipoSede (IdTipoSede) on update no action on delete no action ;
Alter Table Impresa add Constraint Relationship287 Foreign Key (IdStatoImpresa) references StatoImpresa (IdStatoImpresa) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship292 Foreign Key (IdPosizioneBancaria) references PosizioneBancaria (IdPosizioneBancaria) on update no action on delete no action ;
Alter Table Impresa_Banca add Constraint Relationship296 Foreign Key (IdPosizioneBancaria) references PosizioneBancaria (IdPosizioneBancaria) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship297 Foreign Key (IdPosizioneBancaria) references PosizioneBancaria (IdPosizioneBancaria) on update no action on delete no action ;
Alter Table Utente_Azione add Constraint Relationship298 Foreign Key (IdAzione) references Azione (IdAzione) on update no action on delete no action ;
Alter Table SedeImpresa_Autorizzazione add Constraint Relationship306 Foreign Key (InpsCa,ValidoDal) references Inps_Autorizzazione (InpsCa,ValidoDal) on update no action on delete no action ;
Alter Table SedeImpresa add Constraint Relationship308 Foreign Key (InpsCsc) references Inps_Csc (InpsCsc) on update no action on delete no action ;
Alter Table Inps_Csc add Constraint Relationship310 Foreign Key (IdInpsClasse,IdInpsRamo) references Inps_Classe (IdInpsClasse,IdInpsRamo) on update no action on delete no action ;
Alter Table Inps_Classe add Constraint Relationship312 Foreign Key (IdInpsRamo) references Inps_Ramo (IdInpsRamo) on update no action on delete no action ;
Alter Table Indirizzo add Constraint Relationship326 Foreign Key (IdToponimo) references Toponimo (IdToponimo) on update no action on delete no action ;
Alter Table ExtraCe add Constraint Relationship379 Foreign Key (IdStatusStraniero) references Co_StatusStraniero (IdStatusStraniero) on update no action on delete no action ;
Alter Table ExtraCe add Constraint Relationship381 Foreign Key (IdPermesso) references Co_PermessoSoggiorno (IdPermesso) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship323 Foreign Key (IdCoSoggetto) references Co_Soggetto (IdCoSoggetto) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship328 Foreign Key (IdIndirizzoResidenza) references Indirizzo (IdIndirizzo) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship329 Foreign Key (IdIndirizzoDomicilio) references Indirizzo (IdIndirizzo) on update no action on delete no action ;
Alter Table PersonaGiuridica add Constraint Relationship330 Foreign Key (IdIndirizzoLegale) references Indirizzo (IdIndirizzo) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship331 Foreign Key (IdIndirizzoDomicilio) references Indirizzo (IdIndirizzo) on update no action on delete no action ;
Alter Table SedeImpresa add Constraint Relationship332 Foreign Key (IdIndirizzo) references Indirizzo (IdIndirizzo) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship347 Foreign Key (IdIndirizzoDomicilio) references Indirizzo (IdIndirizzo) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship348 Foreign Key (IdIndirizzoDomicilio2) references Indirizzo (IdIndirizzo) on update no action on delete no action ;
Alter Table Cantiere add Constraint Relationship361 Foreign Key (IdIndirizzo) references Indirizzo (IdIndirizzo) on update no action on delete no action ;
Alter Table Indirizzo add Constraint Relationship327 Foreign Key (IdTipoIndirizzo) references TipoIndirizzo (IdTipoIndirizzo) on update no action on delete no action ;
Alter Table Utente_Azione add Constraint Relationship340 Foreign Key (IdTarget) references Target (IdTarget) on update no action on delete no action ;
Alter Table Utente add Constraint Relationship342 Foreign Key (IdRuolo) references Ruolo (IdRuolo) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship352 Foreign Key (IdTipoLavoratoreStat) references TipoLavoratoreStat (IdTipoLavoratoreStat) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship353 Foreign Key (IdTipoDatore) references TipoDatore (IdTipoDatore) on update no action on delete no action ;
Alter Table Impresa add Constraint Relationship357 Foreign Key (IdTipoDatore) references TipoDatore (IdTipoDatore) on update no action on delete no action ;
Alter Table AE_Destinazione5M add Constraint Relationship355 Foreign Key (IdAeTipoDestinazione) references Ae_TipoDestinazione5M (IdAeTipoDestinazione) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship356 Foreign Key (IdDestinazione5M) references AE_Destinazione5M (IdDestinazione5M) on update no action on delete no action ;
Alter Table Sindacato add Constraint Relationship358 Foreign Key (IdTipoSindacato) references TipoSindacato (IdTipoSindacato) on update no action on delete no action ;
Alter Table Lavoratore add Constraint Relationship359 Foreign Key (IdTipoSindacato) references TipoSindacato (IdTipoSindacato) on update no action on delete no action ;
Alter Table Cnce_Subappalto add Constraint Relationship391 Foreign Key (IdImpresa,IdCantiere) references Cantiere (IdImpresa,IdCantiere) on update no action on delete no action ;
Alter Table Cantiere add Constraint Relationship362 Foreign Key (IdTipocommittente) references Cnce_TipoCommittente (IdTipocommittente) on update no action on delete no action ;
Alter Table Cantiere add Constraint Relationship363 Foreign Key (IdTipoAttivita) references Cnce_TipoAttivita (IdTipoAttivita) on update no action on delete no action ;
Alter Table Cantiere add Constraint Relationship364 Foreign Key (IdSituazione) references Cnce_SituazioneCantiere (IdSituazione) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship370 Foreign Key (IdSmtpAccount) references SmtpAccount (IdSmtpAccount) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship377 Foreign Key (IdTipoOccupazione) references TipoOccupazione (IdTipoOccupazione) on update no action on delete no action ;
Alter Table ExtraCe add Constraint Relationship380 Foreign Key (IdQuestura) references Questura (IdQuestura) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship382 Foreign Key (IdExtraCe) references ExtraCe (IdExtraCe) on update no action on delete no action ;
Alter Table PersonaGiuridica add Constraint Relationship385 Foreign Key (IdContatto) references Contatto (IdContatto) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship386 Foreign Key (IdContatto) references Contatto (IdContatto) on update no action on delete no action ;
Alter Table SedeImpresa add Constraint Relationship387 Foreign Key (IdContatto) references Contatto (IdContatto) on update no action on delete no action ;
Alter Table PersonaFisica add Constraint Relationship388 Foreign Key (IdContatto) references Contatto (IdContatto) on update no action on delete no action ;
Alter Table Cnce_Impresa add Constraint Relationship392 Foreign Key (IdTipoContratto) references Cnce_TipoContratto (IdTipoContratto) on update no action on delete no action ;
Alter Table Cantiere add Constraint Relationship393 Foreign Key (IdTipoLavoro) references Cnce_TipoLavoro (IdTipoLavoro) on update no action on delete no action ;
Alter Table EntePubblico add Constraint Relationship399 Foreign Key (IdEnteAppartenenza) references EntePubblico (IdEnte) on update no action on delete no action ;
Alter Table SubordinatoPa add Constraint Relationship413 Foreign Key (IdEnte) references EntePubblico (IdEnte) on update no action on delete no action ;
Alter Table SubordinatoPa add Constraint Relationship414 Foreign Key (IdSedeServizio) references EntePubblico (IdEnte) on update no action on delete no action ;
Alter Table Sp_Impresa add Constraint Relationship416 Foreign Key (IdCategoria) references Sp_Categoria (IdCategoria) on update no action on delete no action ;
Alter Table Firmatario add Constraint Relationship422 Foreign Key (IdTipoCarica) references AE_TipoCarica (IdTipoCarica) on update no action on delete no action ;
Alter Table PersonaGiuridica add Constraint Relationship423 Foreign Key (IdFirmatario) references Firmatario (IdFirmatario) on update no action on delete no action ;
Alter Table Cantiere_CnceLav add Constraint Relationship427 Foreign Key (IdImpresa,IdCantiere) references Cantiere (IdImpresa,IdCantiere) on update no action on delete no action ;
Alter Table Cantiere_CnceLav add Constraint Relationship428 Foreign Key (IdLavoratore) references Cnce_Lavoratore (IdLavoratore) on update no action on delete no action ;
Alter Table TitolareDati add Constraint Relationship429 Foreign Key (IdTipoCarica) references AE_TipoCarica (IdTipoCarica) on update no action on delete no action ;
Alter Table StatoArea add Constraint Relationship430 Foreign Key (IdContinente) references Continente (IdContinente) on update no action on delete no action ;

COMMIT WORK;


/******************************************************************************/
/****                                Views		                           ****/
/******************************************************************************/

CREATE VIEW VIEW_SUBORDINATO AS
SELECT LAVORATORE.IDLAVORATORE, LAVORATORE.IDIMPRESA, SUBORDINATO.IDASSUNZIONE, LAVORATORE.ASSUNZIONEDATA, PERSONAFISICA.COGNOME,
PERSONAFISICA.NOME, SUBORDINATO.IDINPSQUALIFICA1, SUBORDINATO.IDINPSQUALIFICA2, SUBORDINATO.IDINPSQUALIFICA3, SUBORDINATO.IDINPSTIPOCONTRIBUZIONE,
SUBORDINATO.IDCONTRATTODETTAGLIO, SUBORDINATO.IDLIVELLO, SUBORDINATO.IDCESSAZIONE, LAVORATORE.CESSAZIONEDATA
FROM SUBORDINATO
LEFT JOIN LAVORATORE ON SUBORDINATO.IDLAVORATORE = LAVORATORE.IDLAVORATORE
LEFT JOIN PERSONAFISICA ON LAVORATORE.IDANAGRAFICA = PERSONAFISICA.IDANAGRAFICA
ORDER BY PERSONAFISICA.COGNOME, PERSONAFISICA.NOME;

-- Creo nuova vista VIEW_PERSONAFISICA
CREATE VIEW VIEW_PERSONAFISICA AS
SELECT PERSONAFISICA.IDANAGRAFICA, PERSONAFISICA.CF, PERSONAFISICA.NOME, PERSONAFISICA.COGNOME, SESSO.SESSO, PERSONAFISICA.NASCITADATA,
STATOCIVILE.IDSTATOCIVILE, STATOCIVILE.DESCRIZIONE AS STATOCIVILE, COMUNE.CODCATASTALE, COMUNE.DENOMINAZIONE AS COMUNERESIDENZA,
REGIONE.CODAGENZIAENTRATE AS CODREGIONE, REGIONE.DENOMINAZIONE AS REGIONE, STATOESTERO.DENOMINAZIONE2 AS CITTADINANZA, ANAGRAFICA.IDTIPOANAGRAFICA, PERSONAFISICA.NASCOSTO
FROM PERSONAFISICA
LEFT JOIN ANAGRAFICA on PERSONAFISICA.IDANAGRAFICA = ANAGRAFICA.IDANAGRAFICA
LEFT JOIN SESSO on PERSONAFISICA.SESSO = SESSO.IDSESSO
LEFT JOIN INDIRIZZO on PERSONAFISICA.IDINDIRIZZORESIDENZA = INDIRIZZO.IDINDIRIZZO
LEFT JOIN COMUNE on INDIRIZZO.IDCOMUNE = COMUNE.IDCOMUNE
LEFT JOIN PROVINCIA on COMUNE.IDPROVINCIA = PROVINCIA.IDPROVINCIA
LEFT JOIN REGIONE on PROVINCIA.IDREGIONE = REGIONE.IDREGIONE
LEFT JOIN STATOCIVILE on PERSONAFISICA.IDSTATOCIVILE = STATOCIVILE.IDSTATOCIVILE
LEFT JOIN STATOESTERO on PERSONAFISICA.CITTADINANZA = STATOESTERO.IDSTATOESTERO
-- WHERE PERSONAFISICA.IDANAGRAFICA > 0 AND (PERSONAFISICA.NASCOSTO <> 1 OR PERSONAFISICA.NASCOSTO IS NULL)
ORDER BY PERSONAFISICA.COGNOME, PERSONAFISICA.NOME;

COMMIT WORK;

/******************************************************************************/
/****                                Exceptions                            ****/
/******************************************************************************/

Create Exception except_del_p 'Children still exist in child table. Cannot delete parent.';
Create Exception except_ins_ch 'Parent does not exist. Cannot create child.';
Create Exception except_upd_ch 'Parent does not exist. Cannot update child.';
Create Exception except_upd_p 'Children still exist in child table. Cannot update parent.';
Create Exception except_ins_ch_card 'Maximum cardinality exceeded. Cannot insert into child.';
Create Exception except_upd_ch_card 'Maximum cardinality exceeded. Cannot update child.';


/******************************************************************************/
/****                                Done                                  ****/
/******************************************************************************/

COMMIT WORK;