-- Created		01/12/2004
-- Modified:	18/10/2019
-- Project		Paghe Open
-- Model		Presenze (Db)
-- Company		Iubar.it (http://www.iubar.it)
-- Author		ing. Andrea Borgogelli Avveduti (info@iubar.it)
-- Version:		01.97.00
-- Database		Firebird

/******************************************************************************/
/****                                DB                                    ****/
/******************************************************************************/

CREATE DATABASE 'localhost:C:\Users\Iubar\AppData\Local\Temp\fdb\presenze.fdb' USER 'SYSDBA' PASSWORD 'masterkey' PAGE_SIZE 4096 DEFAULT CHARACTER SET UTF8;

SET ECHO OFF ;

/******************************************************************************/
/****                                Domains                               ****/
/******************************************************************************/

Create Domain Note As Varchar(500);
Create Domain Booleanint As Smallint CHECK (value is null or value in (0, 1));
Create Domain Arithmetic As Decimal(6,2);


SET ECHO ON ;

/******************************************************************************/
/****                                Tables                                ****/
/******************************************************************************/

SET ECHO OFF ;


Create Table Riepilogo  (
	IdLavoratore Integer NOT NULL,
	Anno Integer NOT NULL,
	Mese Smallint NOT NULL,
	IdDatoRetributivo Integer NOT NULL,
	IdPosizione Integer,
	IdImpresa Integer,
	IdSedeImpresa Smallint,
	LavOrdinarioOre Integer,
	LavStraordinarioOre Integer,
	AssenzaOre Integer,
	AssenzaGiorni Integer,
	MalattiaGiorni Smallint,
	InfortunioGiorni Smallint,
	PermessoOre Integer,
	PermessoGiorni Integer,
	FerieOre Integer,
	FerieGiorni Smallint,
Constraint pk_Riepilogo Primary Key (IdLavoratore,Anno,Mese,IdDatoRetributivo)
);

Create Table TipoAssenzaPresenza  (
	IdTipoAssenza Integer NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoAssenzaPresenza Primary Key (IdTipoAssenza)
);

Create Table Timbratura  (
	IdTimbratura Integer NOT NULL,
	IdBadge Integer,
	IdRilevatore Integer,
	Orario Time,
	Data Date,
	DataOra Timestamp,
	Entrata Booleanint,
	Uscita Booleanint,
	Cf Varchar(20),
Constraint pk_Timbratura Primary Key (IdTimbratura)
);

Create Table LibroInfortunio  (
	IdInfortunioGlobale Integer NOT NULL,
	IdConseguenza Integer NOT NULL,
	IdAnagrafica Integer,
	IdAzienda Integer,
	IdInfortunioAziendale Integer,
	DataInserimento Date,
	DataInfortunio Date,
	DataRipresaLavoro Date,
	DescrizioneCausa Varchar(200),
	NaturaLesione Varchar(200),
	SedeLesione Varchar(200),
	IdReparto Integer,
	IdQualificaProfessionale Integer,
Constraint pk_LibroInfortunio Primary Key (IdInfortunioGlobale)
);

Create Table Conseguenza  (
	IdConseguenza Integer NOT NULL,
	Descrizione Varchar(200),
Constraint pk_Conseguenza Primary Key (IdConseguenza)
);

Create Table DbInfo  (
	Id Smallint NOT NULL,
	Descrizione Varchar(200),
	Valore Note,
Constraint pk_DbInfo Primary Key (Id)
);

Create Table Presenza  (
	IdLavoratore Integer NOT NULL,
	Data Date NOT NULL,
	IdMaggiorazione Smallint NOT NULL,
	Ore Decimal(5,2) NOT NULL,
	GiornoIntero Booleanint,
	IdInpsQualifica1 Varchar(2) NOT NULL,
	IdSoggetto Integer,
	IdImpresa Integer,
	IdSedeImpresa Smallint,
	IdCantiere Smallint,
	IdContrattoDettaglio Integer,
	IdDatoRetributivo Integer,
Constraint pk_Presenza Primary Key (IdLavoratore,Data,IdMaggiorazione)
);

Create Table TipoOre  (
	IdTipoOre Integer NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoOre Primary Key (IdTipoOre)
);

Create Table Badge  (
	IdBadge Integer NOT NULL,
	IdTipoBadge Smallint,
	IdSoggetto Integer,
	IdImpresa Integer,
	DataAssunzione Date,
	Codice Varchar(50),
	Note Note,
Constraint pk_Badge Primary Key (IdBadge)
);

Create Table Rilevatore  (
	IdRilevatore Integer NOT NULL,
	IdTipoRilevatore Smallint,
	IdImpresa Integer,
	IdSedeImpresa Smallint,
	Note Note,
Constraint pk_Rilevatore Primary Key (IdRilevatore)
);

Create Table FieldMap  (
	IdImpresa Integer NOT NULL,
	IdField Smallint NOT NULL,
	Nome Varchar(200) NOT NULL,
Constraint pk_FieldMap Primary Key (IdImpresa,IdField)
);

Create Table FieldOption  (
	IdImpresa Integer NOT NULL,
	IdOpzione Smallint NOT NULL,
	Valore Varchar(200) NOT NULL,
Constraint pk_FieldOption Primary Key (IdImpresa,IdOpzione)
);

Create Table FieldName  (
	IdField Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_FieldName Primary Key (IdField)
);

Create Table FieldTipoOpzione  (
	IdOpzione Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_FieldTipoOpzione Primary Key (IdOpzione)
);

Create Table Festivita  (
	IdFestivita Integer NOT NULL,
	IdTipoFestivita Smallint NOT NULL,
	IdCalendario Smallint NOT NULL,
	IdComune Varchar(8),
	IdContrattoDettaglio Integer,
	Periodica Smallint,
	Giorno Smallint,
	Mese Smallint,
	Anno Integer,
	Descrizione Varchar(200),
	Note Note,
Constraint pk_Festivita Primary Key (IdFestivita,IdCalendario)
);

Create Table TipoFestivita  (
	IdTipoFestivita Smallint NOT NULL,
	Descrizione Varchar(200),
	DiLegge Booleanint,
	Nascosto Booleanint,
Constraint pk_TipoFestivita Primary Key (IdTipoFestivita)
);

Create Table TipoFestivita2  (
	IdTipoFestivita2 Smallint NOT NULL,
	Descrizione Varchar(200),
Constraint pk_TipoFestivita2 Primary Key (IdTipoFestivita2)
);

Create Table Orario  (
	IdOrario Integer NOT NULL,
	Descrizione Varchar(200),
	IdImpresa Integer,
	Lun Arithmetic,
	Mar Arithmetic,
	Mer Arithmetic,
	Gio Arithmetic,
	Ven Arithmetic,
	Sab Arithmetic,
	Dom Arithmetic,
	IdInpsQualifica1 Varchar(2),
	IdInpsQualifica2 Varchar(2),
	IdTipoLavoratore2 Smallint,
	GiornoZeroOre Smallint,
	GiornoRiposo Smallint,
	OrarioRidotto Booleanint,
	OreMese Arithmetic,
	OreAnno Arithmetic,
	Note Note,
Constraint pk_Orario Primary Key (IdOrario)
);

/*
Create Table OreGiornoSettimana  (
	IdOrario2 Integer NOT NULL,
	IdSettimanaAnno Smallint NOT NULL,
	IdGiornoSett Smallint NOT NULL,
	Ore Arithmetic,
	DefaultValue Booleanint,
Constraint pk_OreGiornoSettimana Primary Key (IdOrario2,IdSettimanaAnno,IdGiornoSett)
);

Create Table OreSettimana  (
	IdOrario2 Integer NOT NULL,
	IdSettimanaAnno Smallint NOT NULL,
	DefaultValue Booleanint,
Constraint pk_OreSettimana Primary Key (IdOrario2,IdSettimanaAnno)
);

Create Table Orario2  (
	IdOrario2 Integer NOT NULL,
	IdTipoOrario2 Smallint,
Constraint pk_Orario2 Primary Key (IdOrario2)
);

Create Table OreMese  (
	IdOrario2 Integer NOT NULL,
	IdMese Smallint NOT NULL,
	DefaultValue Booleanint,
Constraint pk_OreMese Primary Key (IdOrario2,IdMese)
);

Create Table OreGiornoMese  (
	IdOrario2 Integer NOT NULL,
	IdMese Smallint NOT NULL,
	IdGiornoMese Smallint NOT NULL,
	Ore Arithmetic,
Constraint pk_OreGiornoMese Primary Key (IdOrario2,IdMese,IdGiornoMese)
);

Create Table OreGiornoSettMese  (
	IdOrario2 Integer NOT NULL,
	IdMese Smallint NOT NULL,
	IdSettimanaMese Smallint NOT NULL,
	IdGiornoSett Smallint NOT NULL,
	Ore Arithmetic,
	DefaultValue Booleanint,
Constraint pk_OreGiornoSettMese Primary Key (IdOrario2,IdMese,IdSettimanaMese,IdGiornoSett)
);

*/

COMMIT WORK;


/******************************************************************************/
/****                                Indexes                               ****/
/******************************************************************************/


Alter Table LibroInfortunio add Constraint Relationship13 Foreign Key (IdConseguenza) references Conseguenza (IdConseguenza) on update no action on delete no action ;
Alter Table Timbratura add Constraint Relationship14 Foreign Key (IdBadge) references Badge (IdBadge) on update no action on delete no action ;
Alter Table Timbratura add Constraint Relationship15 Foreign Key (IdRilevatore) references Rilevatore (IdRilevatore) on update no action on delete no action ;
Alter Table FieldMap add Constraint Relationship16 Foreign Key (IdField) references FieldName (IdField) on update no action on delete no action ;
Alter Table FieldOption add Constraint Relationship17 Foreign Key (IdOpzione) references FieldTipoOpzione (IdOpzione) on update no action on delete no action ;
Alter Table Festivita add Constraint Relationship18 Foreign Key (IdTipoFestivita) references TipoFestivita (IdTipoFestivita) on update no action on delete no action ;
/*
Alter Table OreGiornoSettimana add Constraint Relationship27 Foreign Key (IdOrario2,IdSettimanaAnno) references OreSettimana (IdOrario2,IdSettimanaAnno) on update no action on delete no action ;
Alter Table OreMese add Constraint Relationship31 Foreign Key (IdOrario2) references Orario2 (IdOrario2) on update no action on delete no action ;
Alter Table OreSettimana add Constraint Relationship33 Foreign Key (IdOrario2) references Orario2 (IdOrario2) on update no action on delete no action ;
Alter Table OreGiornoMese add Constraint Relationship30 Foreign Key (IdOrario2,IdMese) references OreMese (IdOrario2,IdMese) on update no action on delete no action ;
Alter Table OreGiornoSettMese add Constraint Relationship35 Foreign Key (IdOrario2,IdMese) references OreMese (IdOrario2,IdMese) on update no action on delete no action ;
*/

COMMIT WORK;


/******************************************************************************/
/****                                Exceptions                            ****/
/******************************************************************************/

Create Exception except_del_p 'Children still exist in child table. Cannot delete parent.';
Create Exception except_ins_ch 'Parent does not exist. Cannot create child.';
Create Exception except_upd_ch 'Parent does not exist. Cannot update child.';
Create Exception except_upd_p 'Children still exist in child table. Cannot update parent.';
Create Exception except_ins_ch_card 'Maximum cardinality exceeded. Cannot insert into child.';
Create Exception except_upd_ch_card 'Maximum cardinality exceeded. Cannot update child.';


/******************************************************************************/
/****                                Done                                  ****/
/******************************************************************************/

COMMIT WORK;


/******************************************************************************/
/****                                DATA                                  ****/
/******************************************************************************/

/*
Connect 'localhost:C:\Users\Iubar\AppData\Local\Temp\fdb\Presenze.fdb'
         USER 'SYSDBA' PASSWORD 'masterkey';
*/

UPDATE OR INSERT INTO DBINFO (ID, DESCRIZIONE, VALORE) VALUES (1, 'Versione del db', '01.97.00');
INSERT INTO DBINFO (ID, DESCRIZIONE, VALORE) VALUES (2, 'Data installazione', CURRENT_DATE);
UPDATE OR INSERT INTO DBINFO (ID, DESCRIZIONE, VALORE) VALUES (4, 'Richiede client versione minima', '01.97.00');

INSERT INTO ORARIO (IDORARIO, DESCRIZIONE, IDIMPRESA, LUN, MAR, MER, GIO, VEN, SAB, DOM, IDINPSQUALIFICA1, IDINPSQUALIFICA2, IDTIPOLAVORATORE2, GIORNOZEROORE, GIORNORIPOSO, NOTE) VALUES ('1', NULL, NULL, '8.00', '8.00', '8.00', '8.00', '8.00', '0.00', '0.00', NULL, NULL, NULL, '7', '1', NULL);

INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('1', 'Codice fiscale');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('2', 'Partita Iva');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('3', 'Codice Inps del lavoratore');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('4', 'Codice del badge o del cartellino del lavoratore');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('5', 'Data (ovvero giorno di riferimento)');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('6', 'Ore lavorate');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('7', 'Orario di ingresso effettivo');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('8', 'Orario di uscita effettivo');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('9', 'Orario timbratura generica');
INSERT INTO FIELDNAME (IDFIELD, DESCRIZIONE) VALUES ('10', 'Campo riservato utile per specificare se la timbratura è riferita all''entrata o alll''uscita del lavoratore');

INSERT INTO FIELDTIPOOPZIONE (IDOPZIONE, DESCRIZIONE) VALUES ('1', 'Numero righe da saltare da inizio file');
INSERT INTO FIELDTIPOOPZIONE (IDOPZIONE, DESCRIZIONE) VALUES ('2', 'Separatore di campo');
INSERT INTO FIELDTIPOOPZIONE (IDOPZIONE, DESCRIZIONE) VALUES ('3', 'Carattere speciale');
INSERT INTO FIELDTIPOOPZIONE (IDOPZIONE, DESCRIZIONE) VALUES ('4', 'Carattere per nuova riga');
INSERT INTO FIELDTIPOOPZIONE (IDOPZIONE, DESCRIZIONE) VALUES ('5', 'Formato delle date');
INSERT INTO FIELDTIPOOPZIONE (IDOPZIONE, DESCRIZIONE) VALUES ('6', 'Formato degli orari');
INSERT INTO FIELDTIPOOPZIONE (IDOPZIONE, DESCRIZIONE) VALUES ('7', 'Strategia');

INSERT INTO TIPOFESTIVITA (IDTIPOFESTIVITA, DESCRIZIONE, DILEGGE, NASCOSTO) VALUES ('1', 'Festività di legge nazionali', '1', '0');
INSERT INTO TIPOFESTIVITA (IDTIPOFESTIVITA, DESCRIZIONE, DILEGGE, NASCOSTO) VALUES ('50', 'Altre festività previste dal contratto', '0', '0');
INSERT INTO TIPOFESTIVITA (IDTIPOFESTIVITA, DESCRIZIONE, DILEGGE, NASCOSTO) VALUES ('100', 'Patrono', '1', '0');
INSERT INTO TIPOFESTIVITA (IDTIPOFESTIVITA, DESCRIZIONE, DILEGGE, NASCOSTO) VALUES ('40', 'Altre festività soppresse', '0', '0');
INSERT INTO TIPOFESTIVITA (IDTIPOFESTIVITA, DESCRIZIONE, DILEGGE, NASCOSTO) VALUES ('41', 'Festività 4.11', '0', '0');
INSERT INTO TIPOFESTIVITA (IDTIPOFESTIVITA, DESCRIZIONE, DILEGGE, NASCOSTO) VALUES ('11', 'Festività vigenti cadenti di domenica', '1', '1');
INSERT INTO TIPOFESTIVITA (IDTIPOFESTIVITA, DESCRIZIONE, DILEGGE, NASCOSTO) VALUES ('12', 'Festività vigenti infrasettimanali', '1', '1');


INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('1', '1', '1', NULL, NULL, '1', '25', '4', NULL, 'Giorno della Liberazione', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('2', '1', '1', NULL, NULL, '1', '1', '5', NULL, 'Festa del lavoro', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('3', '1', '1', NULL, NULL, '1', '2', '6', NULL, 'Festa della Repubblica', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('4', '1', '1', NULL, NULL, '1', '1', '1', NULL, 'Capodanno', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('5', '1', '1', NULL, NULL, '1', '6', '1', NULL, 'Epifania', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('6', '1', '1', NULL, NULL, '1', '15', '8', NULL, 'Assunzione della Beata Vergine Maria', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('7', '1', '1', NULL, NULL, '1', '1', '11', NULL, 'Ognissanti', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('8', '1', '1', NULL, NULL, '1', '8', '12', NULL, 'Immacolata Concezione', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('9', '1', '1', NULL, NULL, '1', '25', '12', NULL, 'Natale', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('10', '1', '1', NULL, NULL, '1', '26', '12', NULL, 'Santo Stefano', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('11', '50', '1', NULL, '-1', '1', '4', '12', NULL, 'Santa Barbara', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('41', '40', '1', NULL, NULL, '1', '19', '3', NULL, 'S. Giuseppe', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('42', '40', '1', NULL, NULL, '1', '29', '6', NULL, 'S. Pietro e Paolo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('43', '41', '1', NULL, NULL, '1', '4', '11', NULL, 'Festa delle forze armate', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('44', '40', '1', NULL, NULL, '0', '21', '5', '2009', 'Ascensione', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('45', '40', '1', NULL, NULL, '0', '11', '6', '2009', 'Corpus Domini', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('46', '40', '1', NULL, NULL, '0', '13', '5', '2010', 'Ascensione', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('47', '40', '1', NULL, NULL, '0', '3', '6', '2010', 'Corpus Domini', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('51', '1', '1', NULL, NULL, '0', '9', '4', '2007', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('52', '1', '1', NULL, NULL, '0', '24', '3', '2008', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('53', '1', '1', NULL, NULL, '0', '13', '4', '2009', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('54', '1', '1', NULL, NULL, '0', '5', '4', '2010', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('101', '100', '1', '015146', NULL, '1', '7', '12', NULL, 'Sant''Ambrogio', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('102', '100', '1', '058091', NULL, '1', '29', '6', NULL, 'Santi Apostoli Pietro e Paolo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('55', '40', '1', NULL, NULL, '0', '23', '6', '2011', 'Corpus Domini', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('56', '40', '1', NULL, NULL, '0', '02', '6', '2011', 'Ascensione', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('57', '1', '1', NULL, NULL, '0', '25', '4', '2011', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('58', '1', '1', NULL, NULL, '0', '17', '3', '2011', '150° Unità Italia', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('59', '1', '1', NULL, NULL, '0', '09', '4', '2012', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('60', '40', '1', NULL, NULL, '0', '07', '6', '2012', 'Corpus Domini', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('61', '40', '1', NULL, NULL, '0', '17', '5', '2012', 'Ascensione', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('62', '1', '1', NULL, NULL, '0', '1', '4', '2013', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('63', '1', '1', NULL, NULL, '0', '21', '4', '2014', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('64', '1', '1', NULL, NULL, '0', '6', '4', '2015', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('65', '1', '1', NULL, NULL, '0', '28', '3', '2016', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('66', '1', '1', NULL, NULL, '0', '17', '4', '2017', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('67', '1', '1', NULL, NULL, '0', '02', '4', '2018', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('68', '1', '1', NULL, NULL, '0', '22', '4', '2019', 'Lunedì dell''Angelo', NULL);
INSERT INTO FESTIVITA (IDFESTIVITA, IDTIPOFESTIVITA, IDCALENDARIO, IDCOMUNE, IDCONTRATTODETTAGLIO, PERIODICA, GIORNO, MESE, ANNO, DESCRIZIONE, NOTE) VALUES ('69', '1', '1', NULL, NULL, '0', '13', '4', '2020', 'Lunedì dell''Angelo', NULL);
COMMIT WORK;

/******************************************************************************/
/****                                Done                                  ****/
/******************************************************************************/